=========
os-traits
=========

`os-traits` is a library containing standardized trait strings.

Traits are strings that represent a feature of some resource provider.  This
library contains the catalog of constants that have been standardized in the
OpenStack community to refer to a particular hardware, virtualization, storage,
network, or device trait.

* Free software: Apache license
* Documentation: https://docs.openstack.org/os-traits/latest/
* Source: http://git.openstack.org/cgit/openstack/os-traits
* Bugs: https://bugs.launchpad.net/os-traits
* Release Notes: https://docs.openstack.org/releasenotes/os-traits
